==> butido-0.1.3.crate: butido-0.1.3/CONTRIBUTING.md <==
# Contributing

This file describes how you can contribute to butido.


## Reporting issues / Questions

If you have a question regarding butido, feel free to send an email to
one of the following addresses

* "matthias.beyer@atos.net"
* or publicly to [the mailinglist]("~matthiasbeyer/butido@lists.sr.ht")


## Submitting patches

Please make sure you `--signoff` your commits/patchmails.
By that you agree to the
[developer certificate](https://developercertificate.org/):

> Developer Certificate of Origin
> Version 1.1
>
> Copyright (C) 2004, 2006 The Linux Foundation and its contributors.
> 1 Letterman Drive
> Suite D4700
> San Francisco, CA, 94129
>
> Everyone is permitted to copy and distribute verbatim copies of this
> license document, but changing it is not allowed.
>
>
> Developer's Certificate of Origin 1.1
>
> By making a contribution to this project, I certify that:
>
> (a) The contribution was created in whole or in part by me and I
>     have the right to submit it under the open source license
>     indicated in the file; or
>
> (b) The contribution is based upon previous work that, to the best
>     of my knowledge, is covered under an appropriate open source
>     license and I have the right under that license to submit that
>     work with modifications, whether created in whole or in part
>     by me, under the same open source license (unless I am
>     permitted to submit under a different license), as indicated
>     in the file; or
>
> (c) The contribution was provided directly to me by some other
>     person who certified (a), (b) or (c) and I have not modified
>     it.
>
> (d) I understand and agree that this project and the contribution
>     are public and that a record of the contribution (including all
>     personal information I submit with it, including my sign-off) is
>     maintained indefinitely and may be redistributed consistent with
>     this project or the open source license(s) involved.


You can submit patches using [git send-email](https://git-send-email.io/)
and send email to the above email addresses.

For the lazy:

```
git format-patch \
    --subject-prefix=butido \
    --to="~matthiasbeyer/butido@lists.sr.ht" \
    --cc="matthias.beyer@atos.net" \
    --cover-letter \
    --numbered \
    --signoff \
    master..HEAD

# Edit the cover letter
$EDITOR ./0000-cover-letter.patch

# And send the patchset
git send-email \
    --no-chain-reply-to \
    --to="~matthiasbeyer/butido@lists.sr.ht" \
    --cc="matthias.beyer@atos.net" \
    ./0*patch
```

==> butido-0.3.0.crate: butido-0.3.0/CONTRIBUTING.md <==
# Contributing

This file describes how you can contribute to butido.


## Reporting issues / Questions

If you have a question regarding butido, feel free to open an issue or write an
email to the authors.


## Submitting patches

Please make sure you `--signoff` your commits/patchmails.
By that you agree to the
[developer certificate](https://developercertificate.org/):

> Developer Certificate of Origin
> Version 1.1
>
> Copyright (C) 2004, 2006 The Linux Foundation and its contributors.
> 1 Letterman Drive
> Suite D4700
> San Francisco, CA, 94129
>
> Everyone is permitted to copy and distribute verbatim copies of this
> license document, but changing it is not allowed.
>
>
> Developer's Certificate of Origin 1.1
>
> By making a contribution to this project, I certify that:
>
> (a) The contribution was created in whole or in part by me and I
>     have the right to submit it under the open source license
>     indicated in the file; or
>
> (b) The contribution is based upon previous work that, to the best
>     of my knowledge, is covered under an appropriate open source
>     license and I have the right under that license to submit that
>     work with modifications, whether created in whole or in part
>     by me, under the same open source license (unless I am
>     permitted to submit under a different license), as indicated
>     in the file; or
>
> (c) The contribution was provided directly to me by some other
>     person who certified (a), (b) or (c) and I have not modified
>     it.
>
> (d) I understand and agree that this project and the contribution
>     are public and that a record of the contribution (including all
>     personal information I submit with it, including my sign-off) is
>     maintained indefinitely and may be redistributed consistent with
>     this project or the open source license(s) involved.
